@@ -3,7 +3,7 @@ cat("this will be hidden; use for general initializations.")
 library(superb)
 library(ggplot2)
 
-## ---- message=FALSE, echo=FALSE, fig.cap="Figure 1: Mean scores along with 95% confidence interval for two groups of students on the quality of learning behavior."----
+## ---- message=FALSE, echo=FALSE, fig.height=4, fig.width=3, fig.cap="**Figure 1**. Mean scores along with 95% confidence interval for two groups of students on the quality of learning behavior."----
 superbPlot(dataFigure1, 
         BSFactors = "grp", 
         variables = "score", 
@@ -12,7 +12,7 @@ superbPlot(dataFigure1,
     labs(title="(stand-alone)\n95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) +
     theme_gray(base_size=16) +
-    scale_x_discrete(labels=c("1" = "Collaborative games", "2" = "Unstructured activity"))
+    scale_x_discrete(labels=c("1" = "Collaborative\ngames", "2" = "Unstructured\nactivity"))
 
 ## ---- message=FALSE, warning=FALSE, echo=TRUE---------------------------------
 t.test(dataFigure1$score[dataFigure1$grp==1], 
@@ -25,7 +25,7 @@ t.test(dataFigure1$score[dataFigure1$grp==1], mu=100)
 ## ---- message=FALSE, echo=TRUE------------------------------------------------
 t.test(dataFigure1$score[dataFigure1$grp==2], mu=105)
 
-## ---- message=FALSE, echo=TRUE, fig.cap="Figure 2: Mean scores along with difference-adjusted 95% confidence interval for two groups of students on the quality of learning behavior."----
+## ---- message=FALSE, echo=TRUE, fig.height=4, fig.width=3, fig.cap="**Figure 2**. Mean scores along with difference-adjusted 95% confidence interval for two groups of students on the quality of learning behavior."----
 superbPlot(dataFigure1, 
         BSFactors = "grp", 
         adjustments=list(purpose = "difference"),  # the only new thing here
@@ -35,9 +35,9 @@ superbPlot(dataFigure1,
     labs(title="Difference-adjusted\n95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) + 
     theme_gray(base_size=16) +
-    scale_x_discrete(labels=c("1" = "Collaborative games", "2" = "Unstructured activity"))
+    scale_x_discrete(labels=c("1" = "Collaborative\ngames", "2" = "Unstructured\nactivity"))
 
-## ---- message=FALSE, echo=TRUE, fig.cap="Figure 3: Two representation of the data with unadjusted (left) and adjusted (right) 95% confidence intervals"----
+## ---- message=FALSE, echo=TRUE, fig.cap="**Figure 3**. Two representation of the data with unadjusted (left) and adjusted (right) 95% confidence intervals"----
 library(gridExtra)
 plt1 <- superbPlot(dataFigure1, 
         BSFactors = "grp", 
@@ -47,7 +47,7 @@ plt1 <- superbPlot(dataFigure1,
     labs(title="(stand-alone)\n95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) +
     theme_gray(base_size=16) +
-    scale_x_discrete(labels=c("1" = "Collaborative games", "2" = "Unstructured activity")) 
+    scale_x_discrete(labels=c("1" = "Collaborative\ngames", "2" = "Unstructured\nactivity")) 
 
 plt2 <- superbPlot(dataFigure1, 
         BSFactors = "grp", 
@@ -58,12 +58,13 @@ plt2 <- superbPlot(dataFigure1,
     labs(title="Difference-adjusted\n95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) + 
     theme_gray(base_size=16) +
-    scale_x_discrete(labels=c("1" = "Collaborative games", "2" = "Unstructured activity")) 
+    scale_x_discrete(labels=c("1" = "Collaborative\ngames", "2" = "Unstructured\nactivity")) 
 
 plt <- grid.arrange(plt1, plt2, ncol=2)
 
-## ---- message=FALSE, echo=TRUE, fig.cap="Figure 4: Two representations of the results with adjusted and unadjusted error bars on the same plot"----
-# generate the two plots, nudging the error bars, using distinct colors, and having the background transparent
+## ---- message=FALSE, echo=TRUE, fig.height=4, fig.width=6, fig.cap="**Figure 4**. Two representations of the results with adjusted and unadjusted error bars on the same plot"----
+# generate the two plots, nudging the error bars, using distinct colors, and 
+# having the second plot's background transparent (with ``makeTransparent()`` )
 plt1 <- superbPlot(dataFigure1, 
         BSFactors = "grp", 
         variables = "score", 
@@ -72,10 +73,9 @@ plt1 <- superbPlot(dataFigure1,
     xlab("Group") + ylab("Score") + 
     labs(title="(red) Difference-adjusted 95% confidence intervals\n(blue) (stand-alone) 95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) +
-    theme_gray(base_size=16) +
-    scale_x_discrete(labels=c("1" = "Collaborative games", "2" = "Unstructured activity")) +
-    theme(panel.background = element_rect(fill = "transparent"),
-         plot.background = element_rect(fill = "transparent", color = "white"))
+    theme_gray(base_size=12) +
+    scale_x_discrete(labels=c("1" = "Collaborative\ngames", "2" = "Unstructured\nactivity")) 
+
 
 plt2 <- superbPlot(dataFigure1, 
         BSFactors = "grp", 
@@ -86,14 +86,12 @@ plt2 <- superbPlot(dataFigure1,
     xlab("Group") + ylab("Score") + 
     labs(title="(red) Difference-adjusted 95% confidence intervals\n(blue) (stand-alone) 95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) + 
-    theme_gray(base_size=16) +
-    scale_x_discrete(labels=c("1" = "Collaborative games", "2" = "Unstructured activity")) +
-    theme(panel.background = element_rect(fill = "transparent"),
-        plot.background = element_rect(fill = "transparent", color = "white"))
+    theme_gray(base_size=12) +
+    scale_x_discrete(labels=c("1" = "Collaborative\ngames", "2" = "Unstructured\nactivity"))
 
 # transform the ggplots into "grob" so that they can be manipulated
 plt1g <- ggplotGrob(plt1)
-plt2g <- ggplotGrob(plt2)
+plt2g <- ggplotGrob(plt2 + makeTransparent() )
 
 # put the two grob onto an empty ggplot (as the positions are the same, they will be overlayed)
 ggplot() + 
